summaryrefslogtreecommitdiff
path: root/sqlbox/db/access.php
diff options
context:
space:
mode:
Diffstat (limited to 'sqlbox/db/access.php')
-rw-r--r--sqlbox/db/access.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/sqlbox/db/access.php b/sqlbox/db/access.php
index 71647d3..9722601 100644
--- a/sqlbox/db/access.php
+++ b/sqlbox/db/access.php
@@ -16,7 +16,7 @@
// along with Moodle. If not, see <http://www.gnu.org/licenses/>.
/**
* Capability definitions for the newmodule module
*
* The capabilities are loaded into the database table when the module is
* installed or updated. Whenever the capability definitions are updated,
@@ -41,7 +41,7 @@
* The variable name for the capability definitions array is $capabilities
*
* @package mod
- * @subpackage newmodule
+ * @subpackage sqlbox
* @copyright 2011 Your Name
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -51,7 +51,7 @@ defined('MOODLE_INTERNAL') || die();
$capabilities = array(
/***************************** remove these comment marks and modify the code as needed
- 'mod/newmodule:view' => array(
+ 'mod/sqlbox:view' => array(
'captype' => 'read',
'contextlevel' => CONTEXT_MODULE,
'legacy' => array(
@@ -63,7 +63,7 @@ $capabilities = array(
)
),
- 'mod/newmodule:submit' => array(
+ 'mod/sqlbox:submit' => array(
'riskbitmask' => RISK_SPAM,
'captype' => 'write',
'contextlevel' => CONTEXT_MODULE,
@@ -16,7 +16,7 @@
// along with Moodle. If not, see <http://www.gnu.org/licenses/>.
/**
- * Capability definitions for the newmodule module
+ * Capability definitions for the sqlbox module
*
* The capabilities are loaded into the database table when the module is